@@ -4,8 +4,9 @@ import os
 import tempfile
 import contextlib
 
-import nose.tools as nt
-from nose.plugins.attrib import attr
+
+import pytest
+import numpy
 
 from bluepyopt import ephys
 
@@ -32,40 +33,40 @@ def yield_blank_hoc(template_name):
 test_morph = ephys.morphologies.NrnFileMorphology(simple_morphology_path)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_create_empty_template():
     """ephys.models: Test creation of empty template"""
     template_name = 'FakeTemplate'
     hoc_template = ephys.models.CellModel.create_empty_template(template_name)
     sim.neuron.h(hoc_template)
-    nt.assert_true(hasattr(sim.neuron.h, template_name))
+    assert hasattr(sim.neuron.h, template_name)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_model():
     """ephys.models: Test Model class"""
     model = ephys.models.Model('test_model')
     model.instantiate(sim=None)
     model.destroy(sim=None)
-    nt.assert_true(isinstance(model, ephys.models.Model))
+    assert isinstance(model, ephys.models.Model)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_cellmodel():
     """ephys.models: Test CellModel class"""
     model = ephys.models.CellModel('test_model', morph=test_morph, mechs=[])
 
-    nt.assert_equal(
-        str(model),
-        'test_model:\n  morphology:\n    %s\n  mechanisms:\n  params:\n' %
+    assert (
+        str(model)
+        == 'test_model:\n  morphology:\n    %s\n  mechanisms:\n  params:\n' %
         simple_morphology_path)
 
     model.instantiate(sim=sim)
     model.destroy(sim=sim)
-    nt.assert_true(isinstance(model, ephys.models.CellModel))
+    assert isinstance(model, ephys.models.CellModel)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_cellmodel_namecheck():
     """ephys.models: Test CellModel class name checking"""
 
@@ -75,7 +76,7 @@ def test_cellmodel_namecheck():
 
     # Test invalid names
     for name in ['3test', '', 'test$', 'test 3']:
-        nt.assert_raises(
+        pytest.raises(
             TypeError,
             ephys.models.CellModel,
             name,
@@ -83,17 +84,17 @@ def test_cellmodel_namecheck():
             mechs=[])
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_load_hoc_template():
     """ephys.models: Test loading of hoc template"""
 
     template_name = 'test_load_hoc'
     hoc_string = ephys.models.CellModel.create_empty_template(template_name)
     ephys.models.HocCellModel.load_hoc_template(sim, hoc_string)
-    nt.ok_(hasattr(sim.neuron.h, template_name))
+    assert hasattr(sim.neuron.h, template_name)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_HocCellModel():
     """ephys.models: Test HOCCellModel class"""
     template_name = 'test_HocCellModel'
@@ -101,10 +102,10 @@ def test_HocCellModel():
     hoc_cell = ephys.models.HocCellModel(
         'test_hoc_model', simple_morphology_path, hoc_string=hoc_string)
     hoc_cell.instantiate(sim)
-    nt.ok_(hoc_cell.icell is not None)
-    nt.ok_(hoc_cell.cell is not None)
+    assert hoc_cell.icell is not None
+    assert hoc_cell.cell is not None
 
-    nt.ok_('simple.swc' in str(hoc_cell))
+    assert 'simple.swc' in str(hoc_cell)
 
     # these should be callable, but don't do anything
     hoc_cell.freeze(None)
@@ -115,16 +116,16 @@ def test_HocCellModel():
     hoc_cell.destroy(sim=sim)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_CellModel_create_empty_cell():
     """ephys.models: Test create_empty_cell"""
     template_name = 'create_empty_cell'
     cell = ephys.models.CellModel.create_empty_cell(template_name, sim)
-    nt.assert_true(callable(cell))
-    nt.assert_true(hasattr(sim.neuron.h, template_name))
+    assert callable(cell)
+    assert hasattr(sim.neuron.h, template_name)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_CellModel_create_hoc():
     """ephys.models: Test create_hoc"""
 
@@ -138,17 +139,17 @@ def test_CellModel_create_hoc():
                                         params=[])
 
     hoc_string = cell_model.create_hoc({})
-    nt.assert_true('begintemplate CellModel' in hoc_string)
-    nt.assert_true('proc replace_axon()' in hoc_string)
+    assert 'begintemplate CellModel' in hoc_string
+    assert 'proc replace_axon()' in hoc_string
     cell_model_hoc = ephys.models.HocCellModel(
         'CellModelHOC',
         simple_morphology_path,
         hoc_string=hoc_string)
 
-    nt.assert_true(isinstance(cell_model_hoc, ephys.models.HocCellModel))
+    assert isinstance(cell_model_hoc, ephys.models.HocCellModel)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_CellModel_destroy():
     """ephys.models: Test CellModel destroy"""
     morph0 = ephys.morphologies.NrnFileMorphology(simple_morphology_path)
@@ -162,24 +163,24 @@ def test_CellModel_destroy():
                                          mechs=[],
                                          params=[])
 
-    nt.assert_true(not hasattr(sim.neuron.h, 'CellModel_destroy'))
+    assert not hasattr(sim.neuron.h, 'CellModel_destroy')
 
     cell_model0.instantiate(sim=sim)
-    nt.assert_true(hasattr(sim.neuron.h, 'CellModel_destroy'))
-    nt.assert_equal(1, len(sim.neuron.h.CellModel_destroy))
+    assert hasattr(sim.neuron.h, 'CellModel_destroy')
+    assert 1 == len(sim.neuron.h.CellModel_destroy)
 
     cell_model1.instantiate(sim=sim)
-    nt.assert_equal(2, len(sim.neuron.h.CellModel_destroy))
+    assert 2 == len(sim.neuron.h.CellModel_destroy)
 
     # make sure cleanup works
     cell_model0.destroy(sim=sim)
-    nt.assert_equal(1, len(sim.neuron.h.CellModel_destroy))
+    assert 1 == len(sim.neuron.h.CellModel_destroy)
 
     cell_model1.destroy(sim=sim)
-    nt.assert_equal(0, len(sim.neuron.h.CellModel_destroy))
+    assert 0 == len(sim.neuron.h.CellModel_destroy)
 
 
-@attr('unit')
+@pytest.mark.unit
 def test_metaparameter():
     """ephys.models: Test model with MetaParameter"""
 
@@ -219,18 +220,18 @@ def test_metaparameter():
                                         mechs=[],
                                         params=[cm, paramA, paramB, paramC])
 
-    nt.assert_raises(Exception,
-                     cell_model.freeze,
-                     {'ParamC': 2.0})
+    pytest.raises(Exception,
+                  cell_model.freeze,
+                  {'ParamC': 2.0})
 
     cell_model.freeze(test_params)
 
     cell_model.instantiate(sim=sim)
 
-    nt.assert_equal(scaler.eval_dist(1.0, 1.0),
-                    '(-1 + 2.0 * math.exp(1 * 0.003)) * 1')
+    assert (scaler.eval_dist(1.0, 1.0)
+            == '(-1 + 2.0 * math.exp(1 * 0.003)) * 1')
 
-    nt.assert_almost_equal(
+    numpy.testing.assert_almost_equal(
         scaler.scale(
             1.0,
             cell_model.icell.apic[0](.5),
@@ -241,8 +242,8 @@ def test_metaparameter():
 
     hoc_code = cell_model.create_hoc(param_values=test_params)
 
-    nt.assert_true('distribute_distance(CellRef.all, "cm", "(-1 + 2.0 * '
-                   'exp(%.17g * 0.003)) * 1")' in hoc_code)
+    assert ('distribute_distance(CellRef.all, "cm", "(-1 + 2.0 * '
+            'exp(%.17g * 0.003)) * 1")' in hoc_code)
 
     cell_model.destroy(sim=sim)
 
